#ifndef QNEWNOTEBOOKDIALOG_H
#define QNEWNOTEBOOKDIALOG_H

#include <QtGui/QDialog>
#include "ui_QNewNotebookDialog.h"
#include "QvernoteAPI.h"

using namespace qvernote::api;

class QNewNotebookDialog : public QDialog
{
    Q_OBJECT

public:
    QNewNotebookDialog(QvernoteAPI* hEvernote, QWidget *parent = 0);
    ~QNewNotebookDialog();

public slots:
	void createNewNotebook();

signals:
	void reloadNotebookList();

private:
    Ui::QNewNotebookDialogClass ui;
    QvernoteAPI* m_hEvernote;
};

#endif // QNEWNOTEBOOKDIALOG_H
